@@ -32,7 +32,6 @@
 #include "ct_filesystem.h"
 #include <optional>
 
-
 class CtMainWin;
 class CtImporterInterface;
 struct ct_imported_node;
@@ -121,6 +120,7 @@ private:
 
 public:
     CtMainWin*   getCtMainWin() { return _pCtMainWin; }
+    bool         get_were_embfiles_opened() { return _embfiles_opened.size(); }
 
 private:
     Glib::RefPtr<Gtk::TextBuffer> _curr_buffer() { return _pCtMainWin->get_text_view().get_buffer(); }
@@ -299,17 +299,16 @@ public:
 
 private:
     // helper for edit actions
-    void          _image_edit_dialog(Glib::RefPtr<Gdk::Pixbuf> rPixbuf,
-                                     Gtk::TextIter insertIter,
-                                     Gtk::TextIter* pIterBound);
-    void          _text_selection_change_case(gchar change_type);
-    int           _table_dialog(Glib::ustring title, bool is_insert);
-    int           _find_previous_indent_margin();
+    void _image_edit_dialog(Glib::RefPtr<Gdk::Pixbuf> rPixbuf,
+                            Gtk::TextIter insertIter,
+                            Gtk::TextIter* pIterBound);
+    void _text_selection_change_case(gchar change_type);
+    int  _find_previous_indent_margin();
 
 public:
-    void          image_insert_png(Gtk::TextIter iter_insert, Glib::RefPtr<Gdk::Pixbuf> pixbuf,
-                                   const Glib::ustring& link, const Glib::ustring& image_justification);
-    void          image_insert_anchor(Gtk::TextIter iter_insert, const Glib::ustring& name, const Glib::ustring& image_justification);
+    void image_insert_png(Gtk::TextIter iter_insert, Glib::RefPtr<Gdk::Pixbuf> pixbuf,
+                          const Glib::ustring& link, const Glib::ustring& image_justification);
+    void image_insert_anchor(Gtk::TextIter iter_insert, const Glib::ustring& name, const Glib::ustring& image_justification);
 
     void _insert_toc_at_pos(Glib::RefPtr<Gtk::TextBuffer> text_buffer, const std::vector<TocEntry>& entries);
 public:
@@ -407,9 +406,9 @@ public:
 
 private:
     // helper for import actions
-    void _import_from_file(CtImporterInterface* importer) noexcept;
+    void _import_from_file(CtImporterInterface* importer, const bool dummy_root = false) noexcept;
     void _import_from_dir(CtImporterInterface* importer, const std::string& custom_dir) noexcept;
-    void _create_imported_nodes(ct_imported_node* imported_nodes);
+    void _create_imported_nodes(ct_imported_node* imported_nodes, const bool dummy_root = false);
 
 public:
     // import actions
@@ -427,6 +426,7 @@ public:
     void import_nodes_from_tomboy_directory() noexcept;
     void import_nodes_from_keepnote_directory() noexcept;
     void import_nodes_from_mempad_file() noexcept;
+    void import_nodes_from_treepad_file() noexcept;
     void import_nodes_from_leo_file() noexcept;
     void import_nodes_from_rednotebook_html() noexcept;
     void import_nodes_from_notecase_html() noexcept;
@@ -435,7 +435,7 @@ private:
     // helper for export actions
     void _export_print(bool save_to_pdf, const fs::path& auto_path, bool auto_overwrite);
     void _export_to_html(const fs::path& auto_path, bool auto_overwrite);
-    void _export_to_txt(bool is_single, const fs::path& auto_path, bool auto_overwrite);
+    void _export_to_txt(const fs::path& auto_path, bool auto_overwrite);
 
     fs::path _get_pdf_filepath(const fs::path& proposed_name);
     fs::path _get_txt_filepath(const fs::path& proposed_name);
@@ -447,8 +447,7 @@ public:
     void export_print();
     void export_to_pdf();
     void export_to_html();
-    void export_to_txt_multiple();
-    void export_to_txt_single();
+    void export_to_txt();
     void export_to_ctd();
 
     void export_to_pdf_auto(const std::string& dir, bool overwrite);
