@@ -213,14 +213,17 @@ void CtConfig::_populate_keyfile_from_data()
     _currentGroup = "editor";
     _uKeyFile->set_string(_currentGroup, "syntax_highlighting", syntaxHighlighting);
     _uKeyFile->set_string(_currentGroup, "auto_syn_highl", autoSynHighl);
-    _uKeyFile->set_string(_currentGroup, "style_scheme", styleSchemeId);
+    _uKeyFile->set_string(_currentGroup, "rt_style_scheme", rtStyleScheme);
+    _uKeyFile->set_string(_currentGroup, "pt_style_scheme", ptStyleScheme);
+    _uKeyFile->set_string(_currentGroup, "ta_style_scheme", taStyleScheme);
     _uKeyFile->set_boolean(_currentGroup, "enable_spell_check", enableSpellCheck);
     _uKeyFile->set_string(_currentGroup, "spell_check_lang", spellCheckLang);
     _uKeyFile->set_boolean(_currentGroup, "show_line_numbers", showLineNumbers);
+    _uKeyFile->set_boolean(_currentGroup, "scroll_beyond_last_line", scrollBeyondLastLine);
     _uKeyFile->set_boolean(_currentGroup, "spaces_instead_tabs", spacesInsteadTabs);
     _uKeyFile->set_integer(_currentGroup, "tabs_width", tabsWidth);
     _uKeyFile->set_integer(_currentGroup, "anchor_size", anchorSize);
-    _uKeyFile->set_integer(_currentGroup, "embfile_size", embfileSize);
+    _uKeyFile->set_integer(_currentGroup, "embfile_icon_size", embfileIconSize);
     _uKeyFile->set_boolean(_currentGroup, "embfile_show_filename", embfileShowFileName);
     _uKeyFile->set_integer(_currentGroup, "embfile_max_size", embfileMaxSize);
     _uKeyFile->set_boolean(_currentGroup, "line_wrapping", lineWrapping);
@@ -270,7 +273,6 @@ void CtConfig::_populate_keyfile_from_data()
     _currentGroup = "table";
     _uKeyFile->set_integer(_currentGroup, "table_rows", tableRows);
     _uKeyFile->set_integer(_currentGroup, "table_columns", tableColumns);
-    _uKeyFile->set_integer(_currentGroup, "table_col_mode", static_cast<int>(tableColMode));
     _uKeyFile->set_integer(_currentGroup, "table_col_width", tableColWidth);
 
     // [fonts]
@@ -282,8 +284,6 @@ void CtConfig::_populate_keyfile_from_data()
 
     // [colors]
     _currentGroup = "colors";
-    _uKeyFile->set_string(_currentGroup, "rt_def_fg", rtDefFg);
-    _uKeyFile->set_string(_currentGroup, "rt_def_bg", rtDefBg);
     _uKeyFile->set_string(_currentGroup, "tt_def_fg", ttDefFg);
     _uKeyFile->set_string(_currentGroup, "tt_def_bg", ttDefBg);
     _uKeyFile->set_string(_currentGroup, "monospace_bg", monospaceBg);
@@ -299,12 +299,13 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "toolbar_ui_list", toolbarUiList);
     _uKeyFile->set_boolean(_currentGroup, "systray", systrayOn);
     _uKeyFile->set_boolean(_currentGroup, "start_on_systray", startOnSystray);
-    _uKeyFile->set_boolean(_currentGroup, "use_appind", useAppInd);
+    //_uKeyFile->set_boolean(_currentGroup, "use_appind", useAppInd);
     _uKeyFile->set_boolean(_currentGroup, "autosave_on", autosaveOn);
     _uKeyFile->set_integer(_currentGroup, "autosave_val", autosaveVal);
     _uKeyFile->set_boolean(_currentGroup, "check_version", checkVersion);
     _uKeyFile->set_boolean(_currentGroup, "word_count", wordCountOn);
     _uKeyFile->set_boolean(_currentGroup, "reload_doc_last", reloadDocLast);
+    _uKeyFile->set_boolean(_currentGroup, "win_title_doc_dir", winTitleShowDocDir);
     _uKeyFile->set_boolean(_currentGroup, "mod_time_sentinel", modTimeSentinel);
     _uKeyFile->set_boolean(_currentGroup, "backup_copy", backupCopy);
     _uKeyFile->set_integer(_currentGroup, "backup_num", backupNum);
@@ -468,16 +469,19 @@ void CtConfig::_populate_data_from_keyfile()
     _currentGroup = "editor";
     _populate_string_from_keyfile("syntax_highlighting", &syntaxHighlighting);
     _populate_string_from_keyfile("auto_syn_highl", &autoSynHighl);
-    _populate_string_from_keyfile("style_scheme", &styleSchemeId);
+    _populate_string_from_keyfile("rt_style_scheme", &rtStyleScheme);
+    _populate_string_from_keyfile("pt_style_scheme", &ptStyleScheme);
+    _populate_string_from_keyfile("ta_style_scheme", &taStyleScheme);
     if (_populate_bool_from_keyfile("enable_spell_check", &enableSpellCheck))
     {
         _populate_string_from_keyfile("spell_check_lang", &spellCheckLang);
     }
     _populate_bool_from_keyfile("show_line_numbers", &showLineNumbers);
+    _populate_bool_from_keyfile("scroll_beyond_last_line", &scrollBeyondLastLine);
     _populate_bool_from_keyfile("spaces_instead_tabs", &spacesInsteadTabs);
     _populate_int_from_keyfile("tabs_width", &tabsWidth);
     _populate_int_from_keyfile("anchor_size", &anchorSize);
-    _populate_int_from_keyfile("embfile_size", &embfileSize);
+    _populate_int_from_keyfile("embfile_icon_size", &embfileIconSize);
     _populate_bool_from_keyfile("embfile_show_filename", &embfileShowFileName);
     _populate_int_from_keyfile("embfile_max_size", &embfileMaxSize);
     _populate_bool_from_keyfile("line_wrapping", &lineWrapping);
@@ -534,11 +538,6 @@ void CtConfig::_populate_data_from_keyfile()
     _currentGroup = "table";
     _populate_int_from_keyfile("table_rows", &tableRows);
     _populate_int_from_keyfile("table_columns", &tableColumns);
-    int table_col_mode;
-    if (_populate_int_from_keyfile("table_col_mode", &table_col_mode))
-    {
-        tableColMode = static_cast<CtTableColMode>(table_col_mode);
-    }
     _populate_int_from_keyfile("table_col_width", &tableColWidth);
 
     // [fonts]
@@ -550,8 +549,6 @@ void CtConfig::_populate_data_from_keyfile()
 
     // [colors]
     _currentGroup = "colors";
-    _populate_string_from_keyfile("rt_def_fg", &rtDefFg);
-    _populate_string_from_keyfile("rt_def_bg", &rtDefBg);
     _populate_string_from_keyfile("tt_def_fg", &ttDefFg);
     _populate_string_from_keyfile("tt_def_bg", &ttDefBg);
     _populate_string_from_keyfile("monospace_bg", &monospaceBg);
@@ -568,11 +565,17 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_bool_from_keyfile("systray", &systrayOn);
     _populate_bool_from_keyfile("start_on_systray", &startOnSystray);
     _populate_bool_from_keyfile("use_appind", &useAppInd);
+    if (useAppInd) {
+        // if coming from pygtk2 version that supports appindicator which we currently do not
+        systrayOn = false;
+        startOnSystray = false;
+    }
     _populate_bool_from_keyfile("autosave_on", &autosaveOn);
     _populate_int_from_keyfile("autosave_val", &autosaveVal);
     _populate_bool_from_keyfile("check_version", &checkVersion);
     _populate_bool_from_keyfile("word_count", &wordCountOn);
     _populate_bool_from_keyfile("reload_doc_last", &reloadDocLast);
+    _populate_bool_from_keyfile("win_title_doc_dir", &winTitleShowDocDir);
     _populate_bool_from_keyfile("mod_time_sentinel", &modTimeSentinel);
     _populate_bool_from_keyfile("backup_copy", &backupCopy);
     _populate_int_from_keyfile("backup_num", &backupNum);
