@@ -54,6 +54,7 @@ CtMainWin::CtMainWin(bool             no_gui,
    _ctTextview(this),
    _ctStateMachine(this)
 {
+    get_style_context()->add_class("ct-app-win");
     if (not _no_gui) {
         set_icon(_pGtkIconTheme->load_icon(CtConst::APP_NAME, 48));
     }
@@ -119,8 +120,9 @@ CtMainWin::CtMainWin(bool             no_gui,
     signal_key_press_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_window_key_press_event), false);
 
     file_autosave_restart();
+    mod_time_sentinel_restart();
 
-    _title_update(false/*saveNeeded*/);
+    window_title_update(false/*saveNeeded*/);
 
     config_apply();
 
@@ -139,23 +141,13 @@ CtMainWin::CtMainWin(bool             no_gui,
     // show status icon if it's needed and also check if systray exists
     if (!_no_gui && _pCtConfig->systrayOn) {
         _pGtkStatusIcon->set_visible(true);
-        Glib::signal_idle().connect_once([&](){
-            if (!_pGtkStatusIcon->is_embedded()) { // is_embedded works only in main event loop
-                if (_pCtConfig->startOnSystray) {
-                    spdlog::warn("Start on systray is enabled but system does not support system trays, starting normally");
-                }
-                _pGtkStatusIcon->set_visible(false);
-                _pCtConfig->systrayOn = false;
-                menu_set_visible_exit_app(false);
-                present();
-            }
-        });
     }
 }
 
 CtMainWin::~CtMainWin()
 {
     _autosave_timout_connection.disconnect();
+    _mod_time_sentinel_timout_connection.disconnect();
     //std::cout << "~CtMainWin" << std::endl;
 }
 
@@ -176,25 +168,22 @@ Gtk::Image* CtMainWin::new_image_from_stock(const std::string& stockImage, Gtk::
     return image;
 }
 
-void CtMainWin::apply_syntax_highlighting(Glib::RefPtr<Gsv::Buffer> text_buffer, const std::string& syntax)
+void CtMainWin::apply_syntax_highlighting(Glib::RefPtr<Gsv::Buffer> text_buffer, const std::string& syntax, const bool forceReApply)
 {
-    if (text_buffer->get_data(CtConst::STYLE_APPLIED_ID))
+    if (not forceReApply and text_buffer->get_data(CtConst::STYLE_APPLIED_ID)) {
         return;
+    }
     if (CtConst::TABLE_CELL_TEXT_ID == syntax)
     {
-        text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(CtConst::STYLE_SCHEME_LIGHT));
+        text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(_pCtConfig->taStyleScheme));
     }
     else if (CtConst::RICH_TEXT_ID == syntax)
     {
-        // dark theme
-        if (get_ct_config()->rtDefFg == CtConst::RICH_TEXT_DARK_FG && get_ct_config()->rtDefBg == CtConst::RICH_TEXT_DARK_BG)
-            text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(CtConst::STYLE_SCHEME_DARK));
-        else
-            text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(CtConst::STYLE_SCHEME_LIGHT));
+        text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(_pCtConfig->rtStyleScheme));
     }
     else
     {
-        text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(_pCtConfig->styleSchemeId));
+        text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(_pCtConfig->ptStyleScheme));
         if (CtConst::PLAIN_TEXT_ID == syntax)
         {
             text_buffer->set_highlight_syntax(false);
@@ -209,6 +198,51 @@ void CtMainWin::apply_syntax_highlighting(Glib::RefPtr<Gsv::Buffer> text_buffer,
     text_buffer->set_data(CtConst::STYLE_APPLIED_ID, (void*)1);
 }
 
+void CtMainWin::reapply_syntax_highlighting(const char target/*'r':RichText, 'p':PlainTextNCode, 't':Table*/)
+{
+    // clean up applied style for created buffers
+    get_tree_store().get_store()->foreach([&](const Gtk::TreePath& /*treePath*/, const Gtk::TreeIter& treeIter)->bool
+    {
+        auto node = get_tree_store().to_ct_tree_iter(treeIter);
+        switch (target) {
+            case 'r': {
+                if (node.get_node_is_rich_text()) {
+                    apply_syntax_highlighting(curr_tree_iter().get_node_text_buffer(), curr_tree_iter().get_node_syntax_highlighting(), true/*forceReApply*/);
+                }
+            } break;
+            case 'p': {
+                if (node.get_node_is_rich_text() and node.get_node_buffer_already_loaded()) {
+                    // let's look for codeboxes
+                    std::list<CtAnchoredWidget*> anchoredWidgets = node.get_embedded_pixbufs_tables_codeboxes_fast();
+                    for (auto pAnchoredWidget : anchoredWidgets) {
+                        if (CtAnchWidgType::CodeBox == pAnchoredWidget->get_type()) {
+                            pAnchoredWidget->apply_syntax_highlighting(true/*forceReApply*/);
+                        }
+                    }
+                }
+                else {
+                    apply_syntax_highlighting(curr_tree_iter().get_node_text_buffer(), curr_tree_iter().get_node_syntax_highlighting(), true/*forceReApply*/);
+                }
+            } break;
+            case 't': {
+                if (node.get_node_is_rich_text() and node.get_node_buffer_already_loaded()) {
+                    // let's look for tables
+                    std::list<CtAnchoredWidget*> anchoredWidgets = node.get_embedded_pixbufs_tables_codeboxes_fast();
+                    for (auto pAnchoredWidget : anchoredWidgets) {
+                        if (CtAnchWidgType::Table == pAnchoredWidget->get_type()) {
+                            pAnchoredWidget->apply_syntax_highlighting(true/*forceReApply*/);
+                        }
+                    }
+                }
+            } break;
+            default:
+                spdlog::debug("bad theme target");
+                break;
+        }
+        return false; /* false for continue */
+    });
+}
+
 Glib::RefPtr<Gsv::Buffer> CtMainWin::get_new_text_buffer(const Glib::ustring& textContent)
 {
     Glib::RefPtr<Gsv::Buffer> rRetTextBuffer;
@@ -382,8 +416,10 @@ Glib::ustring CtMainWin::sourceview_hovering_link_get_tooltip(const Glib::ustrin
     Glib::ustring tooltip;
     if (link_entry.type == "") { // case when link has wrong format
         tooltip = str::replace(link, "amp;", "");
-    } 
-    else if (link_entry.type == CtConst::LINK_TYPE_FILE) {
+    }
+    else if (link_entry.type == CtConst::LINK_TYPE_WEBS) {
+        tooltip = str::replace(link_entry.webs, "amp;", "");
+    } else if (link_entry.type == CtConst::LINK_TYPE_FILE) {
         tooltip = link_entry.file;
     } else if (link_entry.type == CtConst::LINK_TYPE_FOLD) {
         tooltip = link_entry.fold;
@@ -490,8 +526,8 @@ void CtMainWin::_reset_CtTreestore_CtTreeview()
 
     _uCtTreestore.reset(new CtTreeStore(this));
     _uCtTreestore->tree_view_connect(_uCtTreeview.get());
-    _uCtTreeview->set_tree_node_name_wrap_width(get_ct_config()->cherryWrapEnabled, get_ct_config()->cherryWrapWidth);
-    _uCtTreeview->get_column(CtTreeView::AUX_ICON_COL_NUM)->set_visible(!get_ct_config()->auxIconHide);
+    _uCtTreeview->set_tree_node_name_wrap_width(_pCtConfig->cherryWrapEnabled, _pCtConfig->cherryWrapWidth);
+    _uCtTreeview->get_column(CtTreeView::AUX_ICON_COL_NUM)->set_visible(!_pCtConfig->auxIconHide);
 
     _tree_just_auto_expanded = false;
     _uCtTreeview->signal_cursor_changed().connect(sigc::mem_fun(*this, &CtMainWin::_on_treeview_cursor_changed));
@@ -534,14 +570,14 @@ void CtMainWin::config_apply()
 
     menu_set_visible_exit_app(_pCtConfig->systrayOn);
 
-    _ctTextview.set_show_line_numbers(get_ct_config()->showLineNumbers);
-    _ctTextview.set_insert_spaces_instead_of_tabs(get_ct_config()->spacesInsteadTabs);
-    _ctTextview.set_tab_width(get_ct_config()->tabsWidth);
-    _ctTextview.set_indent(get_ct_config()->wrappingIndent);
-    _ctTextview.set_pixels_above_lines(get_ct_config()->spaceAroundLines);
-    _ctTextview.set_pixels_below_lines(get_ct_config()->spaceAroundLines);
-    _ctTextview.set_pixels_inside_wrap(get_ct_config()->spaceAroundLines, get_ct_config()->relativeWrappedSpace);
-    _ctTextview.set_wrap_mode(get_ct_config()->lineWrapping ? Gtk::WrapMode::WRAP_WORD_CHAR : Gtk::WrapMode::WRAP_NONE);
+    _ctTextview.set_show_line_numbers(_pCtConfig->showLineNumbers);
+    _ctTextview.set_insert_spaces_instead_of_tabs(_pCtConfig->spacesInsteadTabs);
+    _ctTextview.set_tab_width(_pCtConfig->tabsWidth);
+    _ctTextview.set_indent(_pCtConfig->wrappingIndent);
+    _ctTextview.set_pixels_above_lines(_pCtConfig->spaceAroundLines);
+    _ctTextview.set_pixels_below_lines(_pCtConfig->spaceAroundLines);
+    _ctTextview.set_pixels_inside_wrap(_pCtConfig->spaceAroundLines, _pCtConfig->relativeWrappedSpace);
+    _ctTextview.set_wrap_mode(_pCtConfig->lineWrapping ? Gtk::WrapMode::WRAP_WORD_CHAR : Gtk::WrapMode::WRAP_NONE);
 
     update_theme();
 }
@@ -580,6 +616,9 @@ void CtMainWin::update_theme()
     css_str += ".ct-view-panel.ct-view-rich-text" + rtFont;
     css_str += ".ct-view-panel.ct-view-plain-text" + plFont;
     css_str += ".ct-view-panel.ct-view-code" + codeFont;
+    if (get_ct_config()->scrollBeyondLastLine) {
+        css_str += ".ct-view-panel { padding-bottom: 400px } ";
+    }
     css_str += ".ct-codebox.ct-view-rich-text" + rtFont;
     css_str += ".ct-codebox.ct-view-plain-text" + codeFont;
     css_str += ".ct-codebox.ct-view-code" + codeFont;
@@ -662,7 +701,7 @@ void CtMainWin::window_header_update()
                 + str::xml_escape(name) + "</span></b>");
 
     // update last visited buttons
-    if (get_ct_config()->nodesOnNodeNameHeader == 0)
+    if (_pCtConfig->nodesOnNodeNameHeader == 0)
     {
         for (auto button: _ctWinHeader.buttonBox.get_children())
             _ctWinHeader.buttonBox.remove(*button);
@@ -670,7 +709,7 @@ void CtMainWin::window_header_update()
     else
     {
         // add more buttons if that is needed
-        while ((int)_ctWinHeader.buttonBox.get_children().size() < get_ct_config()->nodesOnNodeNameHeader)
+        while ((int)_ctWinHeader.buttonBox.get_children().size() < _pCtConfig->nodesOnNodeNameHeader)
         {
             Gtk::Button* button = Gtk::manage(new Gtk::Button(""));
             auto click = [this](Gtk::Button* button) {
@@ -926,7 +965,7 @@ bool CtMainWin::file_open(const fs::path& filepath, const std::string& node_to_f
 
     _uCtStorage.reset(new_storage);
 
-    _title_update(false/*saveNeeded*/);
+    window_title_update(false/*saveNeeded*/);
     menu_set_bookmark_menu_items();
     bool can_vacuum = fs::get_doc_type(_uCtStorage->get_file_path()) == CtDocType::SQLite;
     _uCtMenu->find_action("ct_vacuum")->signal_set_visible.emit(can_vacuum);
@@ -975,7 +1014,7 @@ bool CtMainWin::file_open(const fs::path& filepath, const std::string& node_to_f
         _ctTextview.grab_focus();
     }
 
-    get_ct_config()->recentDocsFilepaths.move_or_push_front(fs::canonical(filepath));
+    _pCtConfig->recentDocsFilepaths.move_or_push_front(fs::canonical(filepath));
     menu_set_items_recent_documents();
 
     return true;
@@ -983,6 +1022,16 @@ bool CtMainWin::file_open(const fs::path& filepath, const std::string& node_to_f
 
 bool CtMainWin::file_save_ask_user()
 {
+    if (_uCtActions->get_were_embfiles_opened()) {
+        const Glib::ustring message = Glib::ustring{"<b>"} +
+            _("Temporary Files were Created and Opened with External Applications.") +
+            "</b>\n\n<b>" + _("Quit the External Applications Before Quit CherryTree.") +
+            "</b>\n\n<b>" + _("Did you Quit the External Applications?") + "</b>";
+        if (not CtDialogs::question_dialog(message, *this)) {
+            return false;
+        }
+    }
+
     if (get_file_save_needed())
     {
         const CtYesNoCancel yesNoCancel = [this]() {
@@ -1057,7 +1106,7 @@ void CtMainWin::file_save_as(const std::string& new_filepath, const Glib::ustrin
     auto on_scope_exit = scope_guard([&](void*) { _pCtConfig->restoreExpColl = old_restore; });
     _pCtConfig->restoreExpColl = CtRestoreExpColl::FROM_STR;
 
-    // instead of setting all inner states, it's easer just to re-open file
+    // instead of setting all inner states, it's easier just to re-open file
     new_storage.reset();               // we don't need it
     update_window_save_not_needed();   // remove asking to save when we close the old file
     file_open(new_filepath, "", password);
@@ -1065,19 +1114,19 @@ void CtMainWin::file_save_as(const std::string& new_filepath, const Glib::ustrin
 
 void CtMainWin::file_autosave_restart()
 {
-    bool was_connected = !_autosave_timout_connection.empty();
+    const bool was_connected = not _autosave_timout_connection.empty();
     _autosave_timout_connection.disconnect();
-    if (!get_ct_config()->autosaveOn) {
+    if (not _pCtConfig->autosaveOn) {
         if (was_connected) spdlog::debug("autosave was stopped");
         return;
     }
-    if (get_ct_config()->autosaveVal < 1) {
+    if (_pCtConfig->autosaveVal < 1) {
         CtDialogs::error_dialog("Wrong timeout for autosave", *this);
         return;
     }
 
     spdlog::debug("autosave is started");
-    _autosave_timout_connection = Glib::signal_timeout().connect_seconds([this]() {        
+    _autosave_timout_connection = Glib::signal_timeout().connect_seconds([this]() {
         if (get_file_save_needed()) {
             spdlog::debug("autosave: time to save file");
             file_save(false);
@@ -1085,7 +1134,32 @@ void CtMainWin::file_autosave_restart()
             spdlog::debug("autosave: no needs to save file");
         }
         return true;
-    }, get_ct_config()->autosaveVal * 60);
+    }, _pCtConfig->autosaveVal * 60);
+}
+
+void CtMainWin::mod_time_sentinel_restart()
+{
+    const bool was_connected = not _mod_time_sentinel_timout_connection.empty();
+    _mod_time_sentinel_timout_connection.disconnect();
+    if (not _pCtConfig->modTimeSentinel) {
+        if (was_connected) spdlog::debug("mod time sentinel was stopped");
+        return;
+    }
+
+    spdlog::debug("mod time sentinel is started");
+    _mod_time_sentinel_timout_connection = Glib::signal_timeout().connect_seconds([this]() {
+        if (user_active() and _uCtStorage->get_mod_time() > 0) {
+            const time_t currModTime = fs::getmtime(_uCtStorage->get_file_path());
+            if (currModTime > _uCtStorage->get_mod_time()) {
+                spdlog::debug("mod time was {} now {}", _uCtStorage->get_mod_time(), currModTime);
+                fs::path file_path = _uCtStorage->get_file_path();
+                if (file_open(file_path, "")) {
+                    _ctStatusBar.update_status(_("The Document was Reloaded After External Update to CT* File"));
+                }
+            }
+        }
+        return true;
+    }, 5/*sec*/);
 }
 
 bool CtMainWin::file_insert_plain_text(const fs::path& filepath)
@@ -1173,22 +1247,22 @@ void CtMainWin::update_selected_node_statusbar_info()
         {
             statusbar_text += separator_text + _("Tags") + _(": ") + treeIter.get_node_tags();
         }
-        if (get_ct_config()->enableSpellCheck && curr_tree_iter().get_node_is_rich_text())
+        if (_pCtConfig->enableSpellCheck && curr_tree_iter().get_node_is_rich_text())
         {
-            statusbar_text += separator_text + _("Spell Check") + _(": ") + get_ct_config()->spellCheckLang;
+            statusbar_text += separator_text + _("Spell Check") + _(": ") + _pCtConfig->spellCheckLang;
         }
-        if (get_ct_config()->wordCountOn)
+        if (_pCtConfig->wordCountOn)
         {
             statusbar_text += separator_text + _("Word Count") + _(": ") + std::to_string(CtTextIterUtil::get_words_count(get_text_view().get_buffer()));
         }
         if (treeIter.get_node_creating_time() > 0)
         {
-            const std::string timestamp_creation = str::time_format(_pCtConfig->timestampFormat, treeIter.get_node_creating_time());
+            const Glib::ustring timestamp_creation = str::time_format(_pCtConfig->timestampFormat, treeIter.get_node_creating_time());
             statusbar_text += separator_text + _("Date Created") + _(": ") + timestamp_creation;
         }
         if (treeIter.get_node_modification_time() > 0)
         {
-            const std::string timestamp_lastsave = str::time_format(_pCtConfig->timestampFormat, treeIter.get_node_modification_time());
+            const Glib::ustring timestamp_lastsave = str::time_format(_pCtConfig->timestampFormat, treeIter.get_node_modification_time());
             statusbar_text += separator_text + _("Date Modified") + _(": ") + timestamp_lastsave;
         }
     }
@@ -1197,7 +1271,7 @@ void CtMainWin::update_selected_node_statusbar_info()
 
 void CtMainWin::update_window_save_not_needed()
 {
-    _title_update(false/*save_needed*/);
+    window_title_update(false/*save_needed*/);
     _fileSaveNeeded = false;
     CtTreeIter treeIter = curr_tree_iter();
     if (treeIter)
@@ -1223,7 +1297,7 @@ void CtMainWin::update_window_save_needed(const CtSaveNeededUpdType update_type,
     }
     if (false == _fileSaveNeeded)
     {
-        _title_update(true/*save_needed*/);
+        window_title_update(true/*save_needed*/);
         _fileSaveNeeded = true;
     }
     switch (update_type)
@@ -1300,7 +1374,14 @@ void CtMainWin::load_buffer_from_state(std::shared_ptr<CtNodeState> state, CtTre
     get_text_view().set_buffer(text_buffer);
     get_text_view().set_spell_check(curr_tree_iter().get_node_is_rich_text());
     text_buffer->place_cursor(text_buffer->get_iter_at_offset(state->cursor_pos));
-    get_text_view().scroll_to(text_buffer->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
+    Glib::signal_idle().connect_once([&](){
+        auto insert_offset = _ctTextview.get_buffer()->get_insert()->get_iter().get_offset();
+        if (_ctTextview.place_cursor_onscreen()) { // scroll if only cursor wasn't visible
+            auto iter = _ctTextview.get_buffer()->get_iter_at_offset(insert_offset);
+            _ctTextview.get_buffer()->place_cursor(iter);
+            _ctTextview.scroll_to(iter, CtTextView::TEXT_SCROLL_MARGIN);
+        }
+    });
 
     user_active() = user_active_restore;
 
@@ -1337,23 +1418,32 @@ void CtMainWin::text_view_apply_cursor_position(CtTreeIter& treeIter, const int
 {
     Glib::RefPtr<Gsv::Buffer> rTextBuffer = treeIter.get_node_text_buffer();
     Gtk::TextIter textIter = rTextBuffer->get_iter_at_offset(cursor_pos);
-    if (static_cast<bool>(textIter))
-    {
-        rTextBuffer->place_cursor(textIter);
-        // if directly call `scroll_to`, it doesn't work maybe textview is not ready/visible or something else
-        Glib::signal_idle().connect_once([&](){
-            auto iter = _ctTextview.get_buffer()->get_insert()->get_iter();
+    // if (static_cast<bool>(textIter)) <- don't check because iter at the end returns false
+
+    rTextBuffer->place_cursor(textIter);
+    // if directly call `scroll_to`, it doesn't work maybe textview is not ready/visible or something else
+    Glib::signal_idle().connect_once([&](){
+        auto insert_offset = _ctTextview.get_buffer()->get_insert()->get_iter().get_offset();
+        if (_ctTextview.place_cursor_onscreen()) { // scroll if only cursor wasn't visible
+            auto iter = _ctTextview.get_buffer()->get_iter_at_offset(insert_offset);
+            _ctTextview.get_buffer()->place_cursor(iter);
             _ctTextview.scroll_to(iter, CtTextView::TEXT_SCROLL_MARGIN);
-        });
-    }
+        }
+    });
 }
 
 void CtMainWin::_on_treeview_cursor_changed()
 {
+    CtTreeIter treeIter = curr_tree_iter();
+    if (not treeIter) {
+        // just removed the last node on the tree?
+        _prevTreeIter = treeIter;
+        return;
+    }
     if (_prevTreeIter)
     {
         const gint64 prevNodeId = _prevTreeIter.get_node_id();
-        if (prevNodeId == curr_tree_iter().get_node_id()) {
+        if (prevNodeId == treeIter.get_node_id()) {
             return;
         }
         Glib::RefPtr<Gsv::Buffer> rTextBuffer = _prevTreeIter.get_node_text_buffer();
@@ -1365,11 +1455,12 @@ void CtMainWin::_on_treeview_cursor_changed()
         }
         _nodesCursorPos[prevNodeId] = rTextBuffer->property_cursor_position();
     }
-    CtTreeIter treeIter = curr_tree_iter();
     _uCtTreestore->text_view_apply_textbuffer(treeIter, &_ctTextview);
     auto mapIter = _nodesCursorPos.find(treeIter.get_node_id());
     if (mapIter != _nodesCursorPos.end() and mapIter->second > 0) {
         text_view_apply_cursor_position(treeIter, mapIter->second);
+    } else {
+        text_view_apply_cursor_position(treeIter, 0);
     }
 
     menu_update_bookmark_menu_item(_uCtTreestore->is_node_bookmarked(treeIter.get_node_id()));
@@ -1408,10 +1499,10 @@ void CtMainWin::_on_treeview_event_after(GdkEvent* event)
 {
     if (event->type == GDK_BUTTON_PRESS and event->button.button == 1)
     {
-        if (get_ct_config()->treeClickFocusText) {
+        if (_pCtConfig->treeClickFocusText) {
             get_text_view().grab_focus();
         }
-        if (get_ct_config()->treeClickExpand)
+        if (_pCtConfig->treeClickExpand)
         {
             _tree_just_auto_expanded = false;
             Gtk::TreePath path_at_click;
@@ -1435,7 +1526,7 @@ void CtMainWin::_on_treeview_event_after(GdkEvent* event)
         // _on_treeview_row_activated works better for double-click
         // but it doesn't work with one click
         // in this case use real double click
-        if (get_ct_config()->treeClickExpand)
+        if (_pCtConfig->treeClickExpand)
         {
             Gtk::TreePath path_at_click;
             if (get_tree_view().get_path_at_pos((int)event->button.x, (int)event->button.y, path_at_click))
@@ -1455,7 +1546,7 @@ void CtMainWin::_on_treeview_row_activated(const Gtk::TreeModel::Path& path, Gtk
     // _on_treeview_row_activated works better for double-click
     // but it doesn't work with one click
     // in this case use real double click
-    if (get_ct_config()->treeClickExpand)
+    if (_pCtConfig->treeClickExpand)
         return;
     if (_uCtTreeview->row_expanded(path))
         _uCtTreeview->collapse_row(path);
@@ -1466,7 +1557,7 @@ void CtMainWin::_on_treeview_row_activated(const Gtk::TreeModel::Path& path, Gtk
 bool CtMainWin::_on_treeview_test_collapse_row(const Gtk::TreeModel::iterator&,const Gtk::TreeModel::Path&)
 {
     // to fix one click
-    if (get_ct_config()->treeClickExpand)
+    if (_pCtConfig->treeClickExpand)
         if (_tree_just_auto_expanded) {
             _tree_just_auto_expanded = false;
             return true;
@@ -1652,7 +1743,6 @@ bool CtMainWin::_on_textview_motion_notify_event(GdkEventMotion* event)
     if (curr_tree_iter().get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID
         and curr_tree_iter().get_node_syntax_highlighting() != CtConst::PLAIN_TEXT_ID)
     {
-        // todo: it's ok to create cursor every time?
         get_text_view().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
         return false;
     }
@@ -1880,16 +1970,22 @@ bool CtMainWin::_on_textview_scroll_event(GdkEventScroll* event)
     return true;
 }
 
-void CtMainWin::_title_update(const bool saveNeeded)
+void CtMainWin::window_title_update(std::optional<bool> saveNeeded)
 {
     Glib::ustring title;
-    if (saveNeeded)
-    {
+    title.reserve(100);
+    if (not saveNeeded.has_value()) {
+        const Glib::ustring currTitle = get_title();
+        saveNeeded = not currTitle.empty() and currTitle.at(0) == '*';
+    }
+    if (saveNeeded.value()) {
         title += "*";
     }
-    if (_uCtStorage->get_file_path() != "")
-    {
-        title += _uCtStorage->get_file_name().string() + " - " + _uCtStorage->get_file_dir().string() + " - ";
+    if (not _uCtStorage->get_file_path().empty()) {
+        title += _uCtStorage->get_file_name().string() + " - ";
+        if (_pCtConfig->winTitleShowDocDir) {
+            title += _uCtStorage->get_file_dir().string() + " - ";
+        }
     }
     title += "CherryTree ";
     title += CtConst::CT_VERSION;
