@@ -1,7 +1,9 @@
 /*
  * ct_parser.cc
  *
- * Copyright 2017-2020 Giuseppe Penone <giuspen@gmail.com>
+ * Copyright 2009-2020
+ * Giuseppe Penone <giuspen@gmail.com>
+ * Evgenii Gurianov <https://github.com/txe>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,22 +30,23 @@
 #include "ct_clipboard.h"
 #include "ct_main_win.h"
 
-
-
-void CtDocumentBuilder::wipe()  
-{ 
+void CtDocumentBuilder::wipe()
+{
     _document = std::make_shared<xmlpp::Document>();
     _current_element = _build_root_el();
 }
 
-xmlpp::Element* CtDocumentBuilder::_build_root_el() {
+xmlpp::Element* CtDocumentBuilder::_build_root_el()
+{
     return _document->create_root_node("root")->add_child("slot")->add_child("rich_text");
 }
 
-CtDocumentBuilder::CtDocumentBuilder(const CtConfig* pCtConfig) : _pCtConfig{pCtConfig}, _current_element{_document->create_root_node("root")->add_child("slot")->add_child("rich_text")} {}
+CtDocumentBuilder::CtDocumentBuilder(const CtConfig* pCtConfig)
+ : _pCtConfig{pCtConfig}
+ , _current_element{_document->create_root_node("root")->add_child("slot")->add_child("rich_text")}
+{}
 
-
-void CtDocumentBuilder::add_image(const std::string& path) noexcept 
+void CtDocumentBuilder::add_image(const std::string& path) noexcept
 {
     try {
         CtXML::image_to_xml(_current_element->get_parent(), path, 0, CtConst::TAG_PROP_VAL_LEFT);
@@ -53,21 +56,22 @@ void CtDocumentBuilder::add_image(const std::string& path) noexcept
     }
 }
 
-void CtDocumentBuilder::add_broken_link(const std::string& link) {
+void CtDocumentBuilder::add_broken_link(const std::string& link)
+{
     _broken_links[link].emplace_back(_current_element);
 }
 
 void CtDocumentBuilder::add_superscript_tag(std::optional<std::string> text)
 {
     _current_element->set_attribute(CtConst::TAG_SCALE, CtConst::TAG_PROP_VAL_SUP);
-    
+
     if (text) add_text(*text);
 }
 
 void CtDocumentBuilder::add_subscript_tag(std::optional<std::string> text)
 {
     _current_element->set_attribute(CtConst::TAG_SCALE, CtConst::TAG_PROP_VAL_SUB);
-    
+
     if (text) add_text(*text);
 }
 
@@ -102,12 +106,12 @@ void CtDocumentBuilder::add_list(uint8_t level, const std::string& data)
     std::string indent;
     auto i_lvl = 0;
     while(i_lvl < level) {
-    ++i_lvl;
-    indent += CtConst::CHAR_TAB;
+        ++i_lvl;
+        indent += CtConst::CHAR_TAB;
+    }
+    add_text(indent + _pCtConfig->charsListbul[level] + CtConst::CHAR_SPACE + data);
 }
 
-add_text(indent + _pCtConfig->charsListbul[level] + CtConst::CHAR_SPACE + data);
-}
 void CtDocumentBuilder::add_weight_tag(const Glib::ustring& level, std::optional<std::string> data)
 {
     _current_element->set_attribute("weight", level);
@@ -138,7 +142,7 @@ void CtDocumentBuilder::add_text(std::string text, bool close_tag /* = true */)
 {
     if (!text.empty()) {
         if (close_tag) close_current_tag();
-    
+
         auto curr_text = _current_element->get_child_text();
         if (!curr_text) _current_element->set_child_text(std::move(text));
         else curr_text->set_content(curr_text->get_content() + std::move(text));
@@ -149,7 +153,8 @@ void CtDocumentBuilder::add_text(std::string text, bool close_tag /* = true */)
     }
 }
 
-void CtDocumentBuilder::with_last_element(const std::function<void()>& func) {
+void CtDocumentBuilder::with_last_element(const std::function<void()>& func)
+{
     xmlpp::Element* curr_tmp = _current_element;
     if (_last_element) _current_element = _last_element;
 
@@ -162,7 +167,8 @@ void CtDocumentBuilder::with_last_element(const std::function<void()>& func) {
     _current_element = curr_tmp;
 }
 
-void CtDocumentBuilder::add_hrule() {
+void CtDocumentBuilder::add_hrule()
+{
     add_text("\n" + _pCtConfig->hRule);
     add_newline();
 }
@@ -176,7 +182,7 @@ void CtDocumentBuilder::close_current_tag()
     }
 }
 
-void CtDocumentBuilder::add_newline() 
+void CtDocumentBuilder::add_newline()
 {
     // Add a newline, if tags are empty no need to close the current tag
     add_text(CtConst::CHAR_NEWLINE, !_open_tags.empty());
@@ -185,37 +191,35 @@ void CtDocumentBuilder::add_newline()
 void CtDocumentBuilder::add_italic_tag(std::optional<std::string> data)
 {
     _current_element->set_attribute(CtConst::TAG_STYLE, CtConst::TAG_PROP_VAL_ITALIC);
-    
+
     if (data) add_tag_data(CtConst::TAG_STYLE, *data);
 }
 
 void CtDocumentBuilder::add_scale_tag(int level, std::optional<std::string> data)
 {
     _current_element->set_attribute(CtConst::TAG_SCALE, fmt::format("h{}", level));
-    
+
     if (data) add_tag_data(CtConst::TAG_SCALE, *data);
 }
 
 
-void CtDocumentBuilder::add_tag_data(std::string_view tag, std::string data) 
+void CtDocumentBuilder::add_tag_data(std::string_view tag, std::string data)
 {
     bool do_close = _open_tags[tag];
-    
+
     add_text(std::move(data), do_close);
     _open_tags[tag] = true;
 }
 
-
-
 void CtDocumentBuilder::add_table(const std::vector<std::vector<std::string>>& table_matrix)
 {
     CtXML::table_to_xml(table_matrix, _current_element->get_parent(), 0, CtConst::TAG_PROP_VAL_LEFT, 40, 400);
     close_current_tag();
 }
 
-
-CtMarkdownFilter::CtMarkdownFilter(std::unique_ptr<CtClipboard> clipboard, Glib::RefPtr<Gtk::TextBuffer> buff, CtConfig* config) : 
-_config(config), _clipboard(std::move(clipboard)) 
+CtMarkdownFilter::CtMarkdownFilter(std::unique_ptr<CtClipboard> clipboard, Glib::RefPtr<Gtk::TextBuffer> buff, CtConfig* config)
+ : _config(config)
+ , _clipboard(std::move(clipboard))
 {
     try {
         buffer(std::move(buff));
@@ -225,7 +229,7 @@ _config(config), _clipboard(std::move(clipboard))
 }
 
 void CtMarkdownFilter::buffer(Glib::RefPtr<Gtk::TextBuffer> text_buffer)
-{   
+{
     // Disconnect previous
     for (auto& sig : _buff_connections) {
         if (sig.connected()) sig.disconnect();
@@ -248,7 +252,6 @@ void CtMarkdownFilter::buffer(Glib::RefPtr<Gtk::TextBuffer> text_buffer)
         _buff_connections[3] = text_buffer->signal_erase().connect(sigc::mem_fun(this, &CtMarkdownFilter::_on_buffer_erase));
     }
 
-
     _buffer = std::move(text_buffer);
 }
 
@@ -261,7 +264,6 @@ void CtMarkdownFilter::reset() noexcept
     }
 }
 
-
 void CtMarkdownFilter::_on_buffer_erase(const Gtk::TextIter& begin, const Gtk::TextIter& end) noexcept
 {
     try {
@@ -305,10 +307,10 @@ void CtMarkdownFilter::_on_buffer_erase(const Gtk::TextIter& begin, const Gtk::T
     }
 }
 
-
-void CtMarkdownFilter::_markdown_insert() {
+void CtMarkdownFilter::_markdown_insert()
+{
     if (active() && (_md_matcher && _md_parser)) {
-        
+
         if (_md_matcher->finished()) {
             auto start_offset = _md_matcher->raw_start_offset();
             auto end_offset = _md_matcher->raw_end_offset();
@@ -327,8 +329,8 @@ void CtMarkdownFilter::_markdown_insert() {
 
             _buffer->place_cursor(iter_begin);
             _buffer->erase(iter_begin, iter_end);
-            
-        
+
+
             _clipboard->from_xml_string_to_buffer(_buffer, _md_parser->xml_doc_string());
 
             auto iter_insert = _buffer->get_insert()->get_iter();
@@ -410,7 +412,8 @@ void CtMarkdownFilter::_on_buffer_insert(const Gtk::TextBuffer::iterator& pos, c
     }
 }
 
-void CtMarkdownFilter::_apply_tag(const Glib::ustring& tag, const Gtk::TextIter& start, const Gtk::TextIter& end) {
+void CtMarkdownFilter::_apply_tag(const Glib::ustring& tag, const Gtk::TextIter& start, const Gtk::TextIter& end)
+{
     spdlog::debug("Applying tag: {}", tag);
     bool has_tag = static_cast<bool>(_buffer->get_tag_table()->lookup(tag));
     if (!has_tag) {
@@ -420,18 +423,21 @@ void CtMarkdownFilter::_apply_tag(const Glib::ustring& tag, const Gtk::TextIter&
     _buffer->apply_tag_by_name(tag, start, end);
 }
 
-std::string CtMarkdownFilter::_get_new_md_tag_name() const {
+std::string CtMarkdownFilter::_get_new_md_tag_name() const
+{
     return fmt::format("md-formatting-{}", _md_matchers.size());
 }
 
-bool CtMarkdownFilter::active() const noexcept 
-{ 
-    return _active && _config->enableMdFormatting; 
+bool CtMarkdownFilter::active() const noexcept
+{
+    return _active && _config->enableMdFormatting;
 }
+
 namespace {
+
 using c_string = std::vector<char>;
 
-std::vector<c_string> split_by_null(std::istream& in) 
+std::vector<c_string> split_by_null(std::istream& in)
 {
     // getline will throw on eof otherwise
     std::vector<c_string> file_strings;
@@ -450,17 +456,16 @@ std::vector<c_string> split_by_null(std::istream& in)
             last = iter + 1;
         }
     }
-    
+
     in.seekg(0, std::ios::beg);
 
     return file_strings;
 }
 
-
-std::vector<CtMempadParser::page> parse_mempad_strings(const std::vector<c_string>& mem_strs) 
+std::vector<CtMempadParser::page> parse_mempad_strings(const std::vector<c_string>& mem_strs)
 {
     // Expected input is something like MeMpAd1.\0\0...\0...\0... etc
-    
+
     std::vector<CtMempadParser::page> parsed_strs;
 
     auto iter = mem_strs.begin() + 2;
@@ -471,7 +476,7 @@ std::vector<CtMempadParser::page> parse_mempad_strings(const std::vector<c_strin
 
         ++iter;
         if (iter == mem_strs.end()) throw std::runtime_error("Unexpected EOF");
-    
+
         std::string contents{iter->begin(), iter->end()};
 
         CtMempadParser::page p{
@@ -487,35 +492,78 @@ std::vector<CtMempadParser::page> parse_mempad_strings(const std::vector<c_strin
 
     return parsed_strs;
 }
-}
+
+} // namespace (anonymous)
 
 void CtMempadParser::feed(std::istream& data)
 {
     /**
      * The mempad data format is pretty simple:
-     * 
+     *
      * Each file has a header which starts with `MeMpAd` then there is an encoding character " " is ASCII . is UTF-8. Then the page number which is max 1-5 characters
      * MeMpAd[.| ][0-9]{0,5}
-     * 
+     *
      * Then each page has a level which is (annoyingly) is raw binary, next is the page name and finally the contents
      */
 
-
-
-    // mempad uses null terminated strings in its format 
-    auto strings = split_by_null(data);
-
+    // mempad uses null terminated strings in its format
+    std::vector<c_string> strings = split_by_null(data);
 
     std::vector<page> new_pages = parse_mempad_strings(strings);
     _parsed_pages.insert(_parsed_pages.cend(), new_pages.begin(), new_pages.end());
-
 }
 
-CtZimParser::CtZimParser(CtConfig* config) : CtDocBuildingParser{config}, _text_parser{std::make_shared<CtTextParser>(_token_schemas())} {}
+void CtTreepadParser::feed(std::istream& data)
+{
+    std::string lineStr;
+    Glib::RefPtr<Glib::Regex> rRegExpInteger = Glib::Regex::create("\\d+");
+    while (std::getline(data, lineStr)) {
+        size_t currSize = lineStr.size();
+        if (currSize > 0 and lineStr.at(currSize - 1) == '\r') {
+            lineStr.erase(currSize - 1);
+        }
+        switch (_currState) {
+            case States::CollectingNodeContent: {
+                if (str::startswith(lineStr, "<end node>")) {
+                    _currState = States::WaitingForNodeTag;
+                }
+                else {
+                    _parsed_pages.back().contents += lineStr + '\n';
+                }
+            } break;
+            case States::WaitingForNodeTag: {
+                if (str::startswith(lineStr, "<node>")) {
+                    _currState = States::WaitingForNodeName;
+                }
+            } break;
+            case States::WaitingForNodeName: {
+                _parsed_pages.emplace_back(CtMempadParser::page{
+                    .level = 0,
+                    .name = lineStr,
+                    .contents = std::string{}
+                });
+                _currState = States::WaitingForNodeLevel;
+            } break;
+            case States::WaitingForNodeLevel: {
+                if (rRegExpInteger->match(lineStr)) {
+                    _parsed_pages.back().level = std::stoi(lineStr);
+                    _currState = States::CollectingNodeContent;
+                }
+                else {
+                    _parsed_pages.back().name += " " + lineStr;
+                }
+            } break;
+        }
+    }
+}
+
+CtZimParser::CtZimParser(CtConfig* config)
+ : CtDocBuildingParser{config}
+ , _text_parser{std::make_shared<CtTextParser>(_token_schemas())}
+{}
 
 void CtZimParser::feed(std::istream& data)
 {
-   
     std::string line;
 
     bool found_header = false;
@@ -526,125 +574,122 @@ void CtZimParser::feed(std::istream& data)
                 // Creation-Date: .* is the final line of the header
                 // TODO: Read the creation date and use it for ts_creation
                 found_header = true;
-                
+
             } else {
                 _parse_body_line(line);
             }
         }
     } catch(const std::ios::failure&) {}
-
 }
 
 std::vector<CtTextParser::token_schema> CtZimParser::_token_schemas()
 {
     return {
-            // Bold
-            {"**", true, true, [this](const std::string& data){
-                doc_builder().close_current_tag();
-                doc_builder().add_weight_tag(CtConst::TAG_PROP_VAL_HEAVY, data);
-                doc_builder().close_current_tag();
-            }},
-            // Indentation detection for lists
-            {"\t", false, false, [this](const std::string& data) {
-                _list_level++;
-                // Did a double match for even number of \t tags
-                if (data.empty()) _list_level++;
-            }},
-            {"https://", false, false, [this](const std::string& data) {
-                doc_builder().close_current_tag();
-                doc_builder().add_link("https://"+data);
-                doc_builder().add_text("https://"+data);
-            }},
-            {"http://", false, false, [this](const std::string& data) {
-                doc_builder().close_current_tag();
-                doc_builder().add_link("http://"+data);
-                doc_builder().add_text("http://"+data);
-            }},
-            // Bullet list
-            {"* ", false, false, [this](const std::string& data) {
-                doc_builder().add_list(_list_level, data);
-                _list_level = 0;
-            }},
-            // Italic
-            {"//", true, true, [this](const std::string& data) {
-                doc_builder().close_current_tag();
-                doc_builder().add_italic_tag(data);
-                doc_builder().close_current_tag();
-            }},
-            // Strikethrough
-            {"~~", true, true, [this](const std::string& data){
-                doc_builder().close_current_tag();
-                doc_builder().add_strikethrough_tag(data);
-                doc_builder().close_current_tag();
-            }},
-            // Headers
-            {"==", false, false, [this](const std::string &data) {
-                int count = 5;
-                auto iter = data.begin();
-                while (*iter == '=') {
-                    count--;
-                    ++iter;
-                }
-                if (count < 0) {
-                    throw CtImportException(fmt::format("Parsing error while parsing header data: {} - Too many '='", data));
-                }
+        // Bold
+        {"**", true, true, [this](const std::string& data){
+            doc_builder().close_current_tag();
+            doc_builder().add_weight_tag(CtConst::TAG_PROP_VAL_HEAVY, data);
+            doc_builder().close_current_tag();
+        }},
+        // Indentation detection for lists
+        {"\t", false, false, [this](const std::string& data) {
+            _list_level++;
+            // Did a double match for even number of \t tags
+            if (data.empty()) _list_level++;
+        }},
+        {"https://", false, false, [this](const std::string& data) {
+            doc_builder().close_current_tag();
+            doc_builder().add_link("https://"+data);
+            doc_builder().add_text("https://"+data);
+        }},
+        {"http://", false, false, [this](const std::string& data) {
+            doc_builder().close_current_tag();
+            doc_builder().add_link("http://"+data);
+            doc_builder().add_text("http://"+data);
+        }},
+        // Bullet list
+        {"* ", false, false, [this](const std::string& data) {
+            doc_builder().add_list(_list_level, data);
+            _list_level = 0;
+        }},
+        // Italic
+        {"//", true, true, [this](const std::string& data) {
+            doc_builder().close_current_tag();
+            doc_builder().add_italic_tag(data);
+            doc_builder().close_current_tag();
+        }},
+        // Strikethrough
+        {"~~", true, true, [this](const std::string& data){
+            doc_builder().close_current_tag();
+            doc_builder().add_strikethrough_tag(data);
+            doc_builder().close_current_tag();
+        }},
+        // Headers
+        {"==", false, false, [this](const std::string &data) {
+            int count = 5;
+            auto iter = data.begin();
+            while (*iter == '=') {
+                count--;
+                ++iter;
+            }
+            if (count < 0) {
+                throw CtImportException(fmt::format("Parsing error while parsing header data: {} - Too many '='", data));
+            }
 
-                if (count > 3) {
-                    // Reset to smaller (h3 currently)
-                    count = 3;
-                }
+            if (count > 3) {
+                // Reset to smaller (h3 currently)
+                count = 3;
+            }
 
-                auto str = str::replace(data, "= ", "");
-                str = str::replace(str, "=", "");
-
-                doc_builder().close_current_tag();
-                doc_builder().add_scale_tag(count, str);
-                doc_builder().close_current_tag();
-            }, "==", true},
-            // External link (e.g https://example.com)
-            {"{{", true, false, [](const std::string&) {
-                // Todo: Implement this (needs image importing)
-            },"}}"},
-            // Todo list
-           // {"[", true, false, links_match_func, "] "},
-            {"[*", true, false, [this](const std::string& data) {
-                doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::ticked, data);
-            }, "]"},
-            {"[x", true, false, [this](const std::string& data) {
-                doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::marked, data);
-            }, "]"},
-            {"[>", true, false, [this](const std::string& data) {
-                doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::marked, data);
-            }, "]"},
-            {"[ ", true, false, [this](const std::string& data) {
-                doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::unchecked, data);
-            }, "]"},
-            // Internal link (e.g MyPage)
-            {"[[", true, false, [this](const std::string& data){
-                doc_builder().close_current_tag();
-                doc_builder().add_broken_link(data);
-                doc_builder().add_text(data);
-                doc_builder().close_current_tag();
-            }, "]]"},
-            // Verbatum - captures all the tokens inside it and print without formatting
-            {"''", true, true, [this](const std::string& data){
-                doc_builder().add_text(data);
-            }, "''", true},
-            // Suberscript
-            {"^{", true, false, [this](const std::string& data){
-                doc_builder().close_current_tag();
-                doc_builder().add_superscript_tag(data);
-                doc_builder().close_current_tag();
-            }, "}"},
-            // Subscript
-            {"_{", true, false, [this](const std::string& data){
-                doc_builder().close_current_tag();
-                doc_builder().add_subscript_tag(data);
-                doc_builder().close_current_tag();
-            }, "}"}
+            auto str = str::replace(data, "= ", "");
+            str = str::replace(str, "=", "");
 
+            doc_builder().close_current_tag();
+            doc_builder().add_scale_tag(count, str);
+            doc_builder().close_current_tag();
+        }, "==", true},
+        // External link (e.g https://example.com)
+        {"{{", true, false, [](const std::string&) {
+            // Todo: Implement this (needs image importing)
+        },"}}"},
+        // Todo list
+       // {"[", true, false, links_match_func, "] "},
+        {"[*", true, false, [this](const std::string& data) {
+            doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::ticked, data);
+        }, "]"},
+        {"[x", true, false, [this](const std::string& data) {
+            doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::marked, data);
+        }, "]"},
+        {"[>", true, false, [this](const std::string& data) {
+            doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::marked, data);
+        }, "]"},
+        {"[ ", true, false, [this](const std::string& data) {
+            doc_builder().add_todo_list(CtDocumentBuilder::checkbox_state::unchecked, data);
+        }, "]"},
+        // Internal link (e.g MyPage)
+        {"[[", true, false, [this](const std::string& data){
+            doc_builder().close_current_tag();
+            doc_builder().add_broken_link(data);
+            doc_builder().add_text(data);
+            doc_builder().close_current_tag();
+        }, "]]"},
+        // Verbatum - captures all the tokens inside it and print without formatting
+        {"''", true, true, [this](const std::string& data){
+            doc_builder().add_text(data);
+        }, "''", true},
+        // Suberscript
+        {"^{", true, false, [this](const std::string& data){
+            doc_builder().close_current_tag();
+            doc_builder().add_superscript_tag(data);
+            doc_builder().close_current_tag();
+        }, "}"},
+        // Subscript
+        {"_{", true, false, [this](const std::string& data){
+            doc_builder().close_current_tag();
+            doc_builder().add_subscript_tag(data);
+            doc_builder().close_current_tag();
+        }, "}"}
     };
-    
 }
 
 void CtZimParser::_parse_body_line(const std::string& line)
@@ -663,14 +708,14 @@ void CtZimParser::_parse_body_line(const std::string& line)
     doc_builder().add_newline();
 }
 
-
 namespace {
-// These hash tables use the tx or t attributes of the node as keys 
+
+// These hash tables use the tx or t attributes of the node as keys
 using name_lookup_table_t = std::unordered_map<std::string, Glib::ustring>;
 using children_lookup_t = std::unordered_map<std::string, std::vector<std::string>>;
 using node_loopup_table_t = std::unordered_map<std::string, CtLeoParser::leo_node>;
 
-CtLeoParser::leo_node parse_leo_t_el(const xmlpp::Element& node) 
+CtLeoParser::leo_node parse_leo_t_el(const xmlpp::Element& node)
 {
     assert(node.get_name() == "t");
 
@@ -683,27 +728,28 @@ CtLeoParser::leo_node parse_leo_t_el(const xmlpp::Element& node)
     return lnode;
 }
 
-std::pair<std::string, Glib::ustring> read_leo_vnode(const xmlpp::Element& v_el) {
+std::pair<std::string, Glib::ustring> read_leo_vnode(const xmlpp::Element& v_el)
+{
     assert(v_el.get_name() == "v");
 
-    
-    auto* vh_el = dynamic_cast<const xmlpp::Element*>(v_el.get_first_child());
-    if (!vh_el) throw std::invalid_argument("v element does not have a <vh> child element!");
-
     std::string tx_id = v_el.get_attribute("t")->get_value();
-    Glib::ustring contents = vh_el->get_child_text()->get_content();
-
-    return {tx_id, contents};
+    if (auto* vh_el = dynamic_cast<const xmlpp::Element*>(v_el.get_first_child())) {
+        Glib::ustring contents = vh_el->get_child_text()->get_content();
+        return {tx_id, contents};
+    } else {
+        return {tx_id, ""};
+    }
 }
 
-void find_node_children(const xmlpp::Element& v_el, children_lookup_t& children) {
+void find_node_children(const xmlpp::Element& v_el, children_lookup_t& children)
+{
     assert(v_el.get_name() == "v");
 
     std::string tx_id = read_leo_vnode(v_el).first;
     for (auto* node : v_el.get_children("v")) {
         if (auto* el = dynamic_cast<xmlpp::Element*>(node)) {
             auto data = read_leo_vnode(*el);
-            
+
             children[tx_id].emplace_back(data.first);
             find_node_children(*el, children);
 
@@ -713,7 +759,8 @@ void find_node_children(const xmlpp::Element& v_el, children_lookup_t& children)
     }
 }
 
-void build_tx_lookup_table(const xmlpp::Node& vnode, name_lookup_table_t& table) {
+void build_tx_lookup_table(const xmlpp::Node& vnode, name_lookup_table_t& table)
+{
     for (auto* node : vnode.get_children("v")) {
         if (auto* el = dynamic_cast<xmlpp::Element*>(node)) {
             table.emplace(read_leo_vnode(*el));
@@ -722,7 +769,8 @@ void build_tx_lookup_table(const xmlpp::Node& vnode, name_lookup_table_t& table)
     }
 }
 
-name_lookup_table_t generate_tx_lookup_table(const xmlpp::Node& vnode_root) {
+name_lookup_table_t generate_tx_lookup_table(const xmlpp::Node& vnode_root)
+{
     assert(vnode_root.get_name() == "vnodes");
 
     name_lookup_table_t tx_id_to_names;
@@ -731,7 +779,8 @@ name_lookup_table_t generate_tx_lookup_table(const xmlpp::Node& vnode_root) {
     return tx_id_to_names;
 }
 
-children_lookup_t generate_children_lookup_table(const xmlpp::Node& vnode_root) {
+children_lookup_t generate_children_lookup_table(const xmlpp::Node& vnode_root)
+{
     assert(vnode_root.get_name() == "vnodes");
     children_lookup_t lookup_tbl;
     for (auto* node : vnode_root.get_children()) {
@@ -746,15 +795,14 @@ children_lookup_t generate_children_lookup_table(const xmlpp::Node& vnode_root)
     return lookup_tbl;
 }
 
-
-void populate_leo_nodes(const xmlpp::Node& vnode_root, node_loopup_table_t& lnodes)  
+void populate_leo_nodes(const xmlpp::Node& vnode_root, node_loopup_table_t& lnodes)
 {
     auto tx_lookup = generate_tx_lookup_table(vnode_root);
     auto child_lookup = generate_children_lookup_table(vnode_root);
 
     for (auto& node_pair : lnodes) {
         auto& node = node_pair.second;
-        node.name = tx_lookup.at(node_pair.first);        
+        node.name = tx_lookup.at(node_pair.first);
         auto node_children = child_lookup.find(node_pair.first);
         if (node_children != child_lookup.end()) {
             for (const auto& child_tx : node_children->second) {
@@ -762,11 +810,10 @@ void populate_leo_nodes(const xmlpp::Node& vnode_root, node_loopup_table_t& lnod
                 node.children.emplace_back(std::move(child));
             }
         }
-    }    
-
+    }
 }
 
-node_loopup_table_t parse_leo_tnodes(const xmlpp::Node& tnodes_root) 
+node_loopup_table_t parse_leo_tnodes(const xmlpp::Node& tnodes_root)
 {
     assert(tnodes_root.get_name() == "tnodes");
 
@@ -783,15 +830,18 @@ node_loopup_table_t parse_leo_tnodes(const xmlpp::Node& tnodes_root)
     return leo_nodes;
 }
 
-xmlpp::Node* find_leo_vnodes_el(const xmlpp::Node& root) {
+xmlpp::Node* find_leo_vnodes_el(const xmlpp::Node& root)
+{
     return root.get_children("vnodes").front();
 }
 
-xmlpp::Node* find_leo_tnodes_el(const xmlpp::Node& root) {
+xmlpp::Node* find_leo_tnodes_el(const xmlpp::Node& root)
+{
     return root.get_children("tnodes").front();
 }
 
-std::vector<CtLeoParser::leo_node> parse_leo_tree(const xmlpp::Node& vnode_root, xmlpp::Node& tnode_root) {
+std::vector<CtLeoParser::leo_node> parse_leo_tree(const xmlpp::Node& vnode_root, xmlpp::Node& tnode_root)
+{
     auto l_nodes = parse_leo_tnodes(tnode_root);
     populate_leo_nodes(vnode_root, l_nodes);
 
@@ -803,7 +853,8 @@ std::vector<CtLeoParser::leo_node> parse_leo_tree(const xmlpp::Node& vnode_root,
     return populated_nodes;
 }
 
-std::vector<CtLeoParser::leo_node> walk_leo_xml(const xmlpp::Node& root) {
+std::vector<CtLeoParser::leo_node> walk_leo_xml(const xmlpp::Node& root)
+{
     auto* vnode = find_leo_vnodes_el(root);
     auto* tnode = find_leo_tnodes_el(root);
 
@@ -811,9 +862,11 @@ std::vector<CtLeoParser::leo_node> walk_leo_xml(const xmlpp::Node& root) {
 
     return parse_leo_tree(*vnode, *tnode);
 }
-}
 
-void CtLeoParser::feed(std::istream& in) {
+} // namespace (anonymous)
+
+void CtLeoParser::feed(std::istream& in)
+{
 
     xmlpp::DomParser p;
     p.parse_stream(in);
@@ -823,4 +876,3 @@ void CtLeoParser::feed(std::istream& in) {
     auto new_nodes = walk_leo_xml(*root);
     _leo_nodes.insert(_leo_nodes.cend(), new_nodes.begin(), new_nodes.end());
 }
-
