@@ -178,6 +178,11 @@ Glib::RefPtr<Gsv::Buffer> CtTreeIter::get_node_text_buffer() const
     return rRetTextBuffer;
 }
 
+bool CtTreeIter::get_node_buffer_already_loaded() const
+{
+    return static_cast<bool>((*this)->get_value(_pColumns->rColTextBuffer));
+}
+
 int CtTreeIter::get_pango_weight_from_is_bold(bool isBold)
 {
     return isBold ? PANGO_WEIGHT_HEAVY : PANGO_WEIGHT_NORMAL;
@@ -204,7 +209,24 @@ std::list<CtAnchoredWidget*> CtTreeIter::get_embedded_pixbufs_tables_codeboxes_f
     if (*this)
     {
         get_node_text_buffer(); // to load buffer\widgets if not loaded
-        return (*this)->get_value(_pColumns->colAnchoredWidgets);
+        // removes invalid widgets (if they were deleted from buffer)
+        std::list<CtAnchoredWidget*> retAnchoredWidgetsList;
+        bool resave_widgets = false;
+        for (CtAnchoredWidget* pCtAnchoredWidget : (*this)->get_value(_pColumns->colAnchoredWidgets))
+        {
+            Glib::RefPtr<Gtk::TextChildAnchor> rChildAnchor = pCtAnchoredWidget->getTextChildAnchor();
+            if (rChildAnchor && !rChildAnchor->get_deleted()) {
+                retAnchoredWidgetsList.push_back(pCtAnchoredWidget);
+            } else {
+                delete pCtAnchoredWidget;
+                resave_widgets = true;
+            }
+        }
+        if (resave_widgets) {
+            (*this)->set_value(_pColumns->colAnchoredWidgets, retAnchoredWidgetsList);
+        }
+
+        return retAnchoredWidgetsList;
     }
     return std::list<CtAnchoredWidget*>();
 }
@@ -484,7 +506,7 @@ void CtTreeStore::text_view_apply_textbuffer(CtTreeIter& treeIter, CtTextView* p
     spdlog::debug("Node name: {}", treeIter.get_node_name());
 
     Glib::RefPtr<Gsv::Buffer> rTextBuffer = treeIter.get_node_text_buffer();
-    _pCtMainWin->apply_syntax_highlighting(rTextBuffer, treeIter.get_node_syntax_highlighting());
+    _pCtMainWin->apply_syntax_highlighting(rTextBuffer, treeIter.get_node_syntax_highlighting(), false/*forceReApply*/);
     pTextView->setup_for_syntax(treeIter.get_node_syntax_highlighting());
     pTextView->set_buffer(rTextBuffer);
     pTextView->set_spell_check(treeIter.get_node_is_rich_text());
@@ -501,7 +523,7 @@ void CtTreeStore::text_view_apply_textbuffer(CtTreeIter& treeIter, CtTextView* p
                 // Gtk::TextIter textIter = rTextBuffer->get_iter_at_child_anchor(rChildAnchor);
                 pTextView->add_child_at_anchor(*pCtAnchoredWidget, rChildAnchor);
                 pCtAnchoredWidget->apply_width_height(pTextView->get_allocation().get_width());
-                pCtAnchoredWidget->apply_syntax_highlighting();
+                pCtAnchoredWidget->apply_syntax_highlighting(false/*forceReApply*/);
             }
             else
             {
@@ -737,7 +759,7 @@ void CtTreeStore::addAnchoredWidgets(Gtk::TreeIter treeIter, std::list<CtAnchore
             {
                 pTextView->add_child_at_anchor(*pCtAnchoredWidget, rChildAnchor);
                 pCtAnchoredWidget->apply_width_height(pTextView->get_allocation().get_width());
-                pCtAnchoredWidget->apply_syntax_highlighting();
+                pCtAnchoredWidget->apply_syntax_highlighting(false/*forceReApply*/);
             }
         }
     }
